#!/usr/bin/python
# encoding: utf-8


from setuptools import setup,find_packages
setup(name='foo-pkg-Liudongbo',
      version='0.1',
      description='a small example',
      url='https://github.com/lwxGitHub123/foo/',
      author='liudongbo',
      author_email='350272438@qq.com',
      license='MIT Licence',
      packages=find_packages(),
      zip_safe=True,
      include_package_data=True,
      platforms="any",
      install_requires=[]
     )
